@@ -43,7 +43,7 @@ update.i_pca <- function(object, incdata, ...) {
   
   # PCA eigenvalues
   sv = eg$d/sqrt(nrows)
-  out$inertia_e=sv/(sum(sv)^2)
+  out$inertia.e=sv/(sum(sv)^2)
   
 #  out$d = eg$d 
   #  out$eg=eg
